pub struct Game {
pub renderer: GPU,
pub camera: Camera,
pub events: Events,
pub time: Time,
pub window: Window,
/* private fields */
}Expand description
Fields
renderer: GPUcamera: Cameraevents: Eventstime: Timewindow: WindowImplementations
Sourceimpl Game
impl Game
Sourcepub fn new<R: Runtime + 'static>(runtime: R) -> OpticResult<Game>
pub fn new<R: Runtime + 'static>(runtime: R) -> OpticResult<Game>
Creates a new game with a 500×500 window and a crimson background.
Initialises:
- A
GPUwith VSync enabled and the given background colour - A perspective
Camera - Gamepad input via
gilrs - The user’s
Runtimeimplementation
Errors
Returns an error if the window, EGL/GLX surface, or gamepad cannot be initialised.
ⓘ
let game = Game::new(MyRuntime)?;Sourcepub fn exit(&mut self)
pub fn exit(&mut self)
Signals the game loop to exit gracefully on the next frame.
After calling this, Runtime::end will be invoked and the process
will exit with SUCCESS.
ⓘ
// In your runtime:
fn update(&mut self, game: &mut Game) {
if game.events.key_down(VirtualKeyCode::Escape) {
game.exit();
}
}Trait Implementations
Sourceimpl ApplicationHandler for Game
impl ApplicationHandler for Game
Sourcefn resumed(&mut self, _el: &ActiveEventLoop)
fn resumed(&mut self, _el: &ActiveEventLoop)
Emitted when the application has been resumed. Read more
Sourcefn window_event(
&mut self,
_el: &ActiveEventLoop,
id: WindowId,
event: WindowEvent,
)
fn window_event( &mut self, _el: &ActiveEventLoop, id: WindowId, event: WindowEvent, )
Emitted when the OS sends an event to a winit window.
Sourcefn about_to_wait(&mut self, el: &ActiveEventLoop)
fn about_to_wait(&mut self, el: &ActiveEventLoop)
Emitted when the event loop is about to block and wait for new events. Read more
Sourcefn new_events(&mut self, event_loop: &ActiveEventLoop, cause: StartCause)
fn new_events(&mut self, event_loop: &ActiveEventLoop, cause: StartCause)
Emitted when new events arrive from the OS to be processed. Read more
Sourcefn user_event(&mut self, event_loop: &ActiveEventLoop, event: T)
fn user_event(&mut self, event_loop: &ActiveEventLoop, event: T)
Emitted when an event is sent from
EventLoopProxy::send_event.Sourcefn device_event(
&mut self,
event_loop: &ActiveEventLoop,
device_id: DeviceId,
event: DeviceEvent,
)
fn device_event( &mut self, event_loop: &ActiveEventLoop, device_id: DeviceId, event: DeviceEvent, )
Emitted when the OS sends an event to a device.
Sourcefn suspended(&mut self, event_loop: &ActiveEventLoop)
fn suspended(&mut self, event_loop: &ActiveEventLoop)
Emitted when the application has been suspended. Read more
Sourcefn exiting(&mut self, event_loop: &ActiveEventLoop)
fn exiting(&mut self, event_loop: &ActiveEventLoop)
Emitted when the event loop is being shut down. Read more
Sourcefn memory_warning(&mut self, event_loop: &ActiveEventLoop)
fn memory_warning(&mut self, event_loop: &ActiveEventLoop)
Emitted when the application has received a memory warning. Read more